from setuptools import setup
# from distutils.core import setup

setup(
    name='smarty-left-pad',
    version='1.0.1',
    packages=['smarty_left_pad'],
    url='https://github.com/nirmalchandra/smarty-left-pad',
    license='Apache 2.0',
    author='Nirmal Chandra',
    author_email='nirmal.fleet@gmail.com',
    description='A python implementation for left-pad'
)
